|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r66696 - in trunk: boost/config boost/config/compiler boost/config/platform libs/config/doc libs/config/doc/html libs/config/doc/html/boost_config
From: admin_at_[hidden]
Date: 2010-11-23 01:33:39
Author: wash
Date: 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
New Revision: 66696
URL: http://svn.boost.org/trac/boost/changeset/66696
Log:
Added *nix identification macros to Boost.Config; BOOST_NIX, BOOST_GENETIC_NIX,
BOOST_TRADEMARK_NIX and BOOST_FUNCTIONAL_NIX.
Text files modified:
trunk/boost/config/compiler/borland.hpp | 3 +
trunk/boost/config/compiler/comeau.hpp | 2
trunk/boost/config/compiler/gcc.hpp | 6 ++
trunk/boost/config/compiler/metrowerks.hpp | 2
trunk/boost/config/compiler/sunpro_cc.hpp | 4 +
trunk/boost/config/platform/aix.hpp | 8 +++
trunk/boost/config/platform/amigaos.hpp | 3 +
trunk/boost/config/platform/beos.hpp | 8 +++
trunk/boost/config/platform/bsd.hpp | 25 ++++++++--
trunk/boost/config/platform/cygwin.hpp | 63 ++++++++++++++-------------
trunk/boost/config/platform/hpux.hpp | 8 +++
trunk/boost/config/platform/irix.hpp | 6 ++
trunk/boost/config/platform/linux.hpp | 8 +++
trunk/boost/config/platform/macos.hpp | 6 ++
trunk/boost/config/platform/qnxnto.hpp | 8 +++
trunk/boost/config/platform/solaris.hpp | 6 ++
trunk/boost/config/platform/symbian.hpp | 10 +++-
trunk/boost/config/platform/vxworks.hpp | 6 ++
trunk/boost/config/suffix.hpp | 4 +
trunk/libs/config/doc/html/boost_config/boost_macro_reference.html | 90 ++++++++++++++++++++++++++++++++++++++++
trunk/libs/config/doc/html/index.html | 4
trunk/libs/config/doc/macro_reference.qbk | 20 ++++++++
22 files changed, 258 insertions(+), 42 deletions(-)
Modified: trunk/boost/config/compiler/borland.hpp
==============================================================================
--- trunk/boost/config/compiler/borland.hpp (original)
+++ trunk/boost/config/compiler/borland.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -12,6 +12,9 @@
//
// versions check:
// we don't support Borland prior to version 5.4:
+
+#define BOOST_BORLAND __BORLANDC__
+
#if __BORLANDC__ < 0x540
# error "Compiler not supported or configured - please reconfigure"
#endif
Modified: trunk/boost/config/compiler/comeau.hpp
==============================================================================
--- trunk/boost/config/compiler/comeau.hpp (original)
+++ trunk/boost/config/compiler/comeau.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -14,6 +14,8 @@
#include "boost/config/compiler/common_edg.hpp"
+#define BOOST_COMO __COMO_VERSION__
+
#if (__COMO_VERSION__ <= 4245)
# if defined(_MSC_VER) && _MSC_VER <= 1300
Modified: trunk/boost/config/compiler/gcc.hpp
==============================================================================
--- trunk/boost/config/compiler/gcc.hpp (original)
+++ trunk/boost/config/compiler/gcc.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -89,6 +89,12 @@
# define BOOST_NO_EXCEPTIONS
#endif
+//
+// Identify cygwin environments
+//
+#if __CYGWIN__
+# define BOOST_CYGWIN
+#endif
//
// Threading support: Turn this on unconditionally here (except for
Modified: trunk/boost/config/compiler/metrowerks.hpp
==============================================================================
--- trunk/boost/config/compiler/metrowerks.hpp (original)
+++ trunk/boost/config/compiler/metrowerks.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -12,6 +12,8 @@
// Metrowerks C++ compiler setup:
+#define BOOST_MWERKS __MWERKS__
+
// locale support is disabled when linking with the dynamic runtime
# ifdef _MSL_NO_LOCALE
# define BOOST_NO_STD_LOCALE
Modified: trunk/boost/config/compiler/sunpro_cc.hpp
==============================================================================
--- trunk/boost/config/compiler/sunpro_cc.hpp (original)
+++ trunk/boost/config/compiler/sunpro_cc.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -11,6 +11,10 @@
// Sun C++ compiler setup:
+// Macro identifying the Sun compiler
+
+#define BOOST_SUNCC __SUNPRO_CC
+
# if __SUNPRO_CC <= 0x500
# define BOOST_NO_MEMBER_TEMPLATES
# define BOOST_NO_FUNCTION_TEMPLATE_ORDERING
Modified: trunk/boost/config/platform/aix.hpp
==============================================================================
--- trunk/boost/config/platform/aix.hpp (original)
+++ trunk/boost/config/platform/aix.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,4 +1,5 @@
// (C) Copyright John Maddock 2001 - 2002.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -9,6 +10,13 @@
#define BOOST_PLATFORM "IBM Aix"
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+#define BOOST_TRADEMARK_NIX 1
+//#define BOOST_FUNCTIONAL_NIX 1
+
+#define BOOST_AIX 1
+
#define BOOST_HAS_UNISTD_H
#define BOOST_HAS_NL_TYPES_H
#define BOOST_HAS_NANOSLEEP
Modified: trunk/boost/config/platform/amigaos.hpp
==============================================================================
--- trunk/boost/config/platform/amigaos.hpp (original)
+++ trunk/boost/config/platform/amigaos.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,4 +1,5 @@
// (C) Copyright John Maddock 2002.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -7,6 +8,8 @@
#define BOOST_PLATFORM "AmigaOS"
+#define BOOST_AMIGA 1
+
#define BOOST_DISABLE_THREADS
#define BOOST_NO_CWCHAR
#define BOOST_NO_STD_WSTRING
Modified: trunk/boost/config/platform/beos.hpp
==============================================================================
--- trunk/boost/config/platform/beos.hpp (original)
+++ trunk/boost/config/platform/beos.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,4 +1,5 @@
// (C) Copyright John Maddock 2001.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -9,6 +10,13 @@
#define BOOST_PLATFORM "BeOS"
+#define BOOST_BEOS 1
+
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+//#define BOOST_TRADEMARK_NIX 1
+#define BOOST_FUNCTIONAL_NIX 1
+
#define BOOST_NO_CWCHAR
#define BOOST_NO_CWCTYPE
#define BOOST_HAS_UNISTD_H
Modified: trunk/boost/config/platform/bsd.hpp
==============================================================================
--- trunk/boost/config/platform/bsd.hpp (original)
+++ trunk/boost/config/platform/bsd.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,6 +1,7 @@
// (C) Copyright John Maddock 2001 - 2003.
// (C) Copyright Darin Adler 2001.
// (C) Copyright Douglas Gregor 2002.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -9,18 +10,30 @@
// generic BSD config options:
-#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__DragonFly__)
-#error "This platform is not BSD"
+#if !defined(__FreeBSD__) && \
+ !defined(__NetBSD__) && \
+ !defined(__OpenBSD__) && \
+ !defined(__DragonFly__)
+ #error "This platform is not BSD"
#endif
+#define BOOST_NIX 1
+#define BOOST_GENETIC_NIX 1
+//#define BOOST_TRADEMARK_NIX 1
+//#define BOOST_FUNCTIONAL_NIX 1
+
#ifdef __FreeBSD__
-#define BOOST_PLATFORM "FreeBSD " BOOST_STRINGIZE(__FreeBSD__)
+ #define BOOST_PLATFORM "FreeBSD " BOOST_STRINGIZE(__FreeBSD__)
+ #define BOOST_FREEBSD __FreeBSD__
#elif defined(__NetBSD__)
-#define BOOST_PLATFORM "NetBSD " BOOST_STRINGIZE(__NetBSD__)
+ #define BOOST_PLATFORM "NetBSD " BOOST_STRINGIZE(__NetBSD__)
+ #define BOOST_NETBSD __NetBSD__
#elif defined(__OpenBSD__)
-#define BOOST_PLATFORM "OpenBSD " BOOST_STRINGIZE(__OpenBSD__)
+ #define BOOST_PLATFORM "OpenBSD " BOOST_STRINGIZE(__OpenBSD__)
+ #define BOOST_OPENBSD __OpenBSD__
#elif defined(__DragonFly__)
-#define BOOST_PLATFORM "DragonFly " BOOST_STRINGIZE(__DragonFly__)
+ #define BOOST_PLATFORM "DragonFly " BOOST_STRINGIZE(__DragonFly__)
+ #define BOOST_DFBSD __DragonFly__
#endif
//
Modified: trunk/boost/config/platform/cygwin.hpp
==============================================================================
--- trunk/boost/config/platform/hpux.hpp (original)
+++ trunk/boost/config/platform/hpux.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -3,6 +3,7 @@
// (C) Copyright David Abrahams 2002.
// (C) Copyright Toon Knapen 2003.
// (C) Copyright Boris Gubenko 2006 - 2007.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -13,6 +14,13 @@
#define BOOST_PLATFORM "HP-UX"
+#define BOOST_HPUX 1 // platform ID macro
+
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+#define BOOST_TRADEMARK_NIX 1
+//#define BOOST_FUNCTIONAL_NIX 1
+
// In principle, HP-UX has a nice <stdint.h> under the name <inttypes.h>
// However, it has the following problem:
// Use of UINT32_C(0) results in "0u l" for the preprocessed source
Modified: trunk/boost/config/platform/irix.hpp
==============================================================================
--- trunk/boost/config/platform/irix.hpp (original)
+++ trunk/boost/config/platform/irix.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,5 +1,6 @@
// (C) Copyright John Maddock 2001 - 2003.
// (C) Copyright Jens Maurer 2003.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -11,6 +12,11 @@
#define BOOST_PLATFORM "SGI Irix"
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+#define BOOST_TRADEMARK_NIX 1
+//#define BOOST_FUNCTIONAL_NIX 1
+
#define BOOST_NO_SWPRINTF
//
// these are not auto detected by POSIX feature tests:
Modified: trunk/boost/config/platform/linux.hpp
==============================================================================
--- trunk/boost/config/platform/linux.hpp (original)
+++ trunk/boost/config/platform/linux.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,5 +1,6 @@
// (C) Copyright John Maddock 2001 - 2003.
// (C) Copyright Jens Maurer 2001 - 2003.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -13,6 +14,13 @@
// make sure we have __GLIBC_PREREQ if available at all
#include <cstdlib>
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+//#define BOOST_TRADEMARK_NIX 1
+#define BOOST_FUNCTIONAL_NIX 1
+
+#define BOOST_LINUX 1
+
//
// <stdint.h> added to glibc 2.1.1
// We can only test for 2.1 though:
Modified: trunk/boost/config/platform/macos.hpp
==============================================================================
--- trunk/boost/config/platform/macos.hpp (original)
+++ trunk/boost/config/platform/macos.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,6 +1,7 @@
// (C) Copyright John Maddock 2001 - 2003.
// (C) Copyright Darin Adler 2001 - 2002.
// (C) Copyright Bill Kempf 2002.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -13,6 +14,11 @@
#if __MACH__ && !defined(_MSL_USING_MSL_C)
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+#define BOOST_TRADEMARK_NIX 1
+//#define BOOST_FUNCTIONAL_NIX 1
+
// Using the Mac OS X system BSD-style C library.
# ifndef BOOST_HAS_UNISTD_H
Modified: trunk/boost/config/platform/qnxnto.hpp
==============================================================================
--- trunk/boost/config/platform/qnxnto.hpp (original)
+++ trunk/boost/config/platform/qnxnto.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,4 +1,5 @@
// (C) Copyright Jim Douglas 2005.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -7,8 +8,15 @@
// QNX specific config options:
+#define BOOST_QNX 1
+
#define BOOST_PLATFORM "QNX"
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+//#define BOOST_TRADEMARK_NIX 1
+#define BOOST_FUNCTIONAL_NIX 1
+
#define BOOST_HAS_UNISTD_H
#include <boost/config/posix_features.hpp>
Modified: trunk/boost/config/platform/solaris.hpp
==============================================================================
--- trunk/boost/config/platform/solaris.hpp (original)
+++ trunk/boost/config/platform/solaris.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,5 +1,6 @@
// (C) Copyright John Maddock 2001 - 2003.
// (C) Copyright Jens Maurer 2003.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -10,6 +11,11 @@
#define BOOST_PLATFORM "Sun Solaris"
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+#define BOOST_TRADEMARK_NIX 1
+//#define BOOST_FUNCTIONAL_NIX 1
+
#define BOOST_HAS_GETTIMEOFDAY
// boilerplate code:
Modified: trunk/boost/config/platform/symbian.hpp
==============================================================================
--- trunk/boost/config/platform/symbian.hpp (original)
+++ trunk/boost/config/platform/symbian.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,6 +1,7 @@
// (C) Copyright Yuriy Krasnoschek 2009.
// (C) Copyright John Maddock 2001 - 2003.
// (C) Copyright Jens Maurer 2001 - 2003.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -9,13 +10,16 @@
// symbian specific config options:
-
#define BOOST_PLATFORM "Symbian"
#define BOOST_SYMBIAN 1
-
#if defined(__S60_3X__)
-// Open C / C++ plugin was introdused in this SDK, earlier versions don't have CRT / STL
+// Open C / C++ plugin was introdused in this SDK, earlier versions don't have
+// CRT / STL
+# define BOOST_NIX 1
+//# define BOOST_GENETIC_NIX 1
+//# define BOOST_TRADEMARK_NIX 1
+# define BOOST_FUNCTIONAL_NIX 1
# define BOOST_S60_3rd_EDITION_FP2_OR_LATER_SDK
// make sure we have __GLIBC_PREREQ if available at all
# include <cstdlib>
Modified: trunk/boost/config/platform/vxworks.hpp
==============================================================================
--- trunk/boost/config/platform/vxworks.hpp (original)
+++ trunk/boost/config/platform/vxworks.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,4 +1,5 @@
// (C) Copyright Dustin Spicuzza 2009.
+// (C) Copyright Bryce Lelbach 2010
// Use, modification and distribution are subject to the
// Boost Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -23,6 +24,11 @@
#define _POSIX_TIMERS 1
#define _POSIX_THREADS 1
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+#define BOOST_TRADEMARK_NIX 1
+//#define BOOST_FUNCTIONAL_NIX 1
+
// vxworks doesn't work with asio serial ports
#define BOOST_ASIO_DISABLE_SERIAL_PORT
Modified: trunk/boost/config/suffix.hpp
==============================================================================
--- trunk/boost/config/suffix.hpp (original)
+++ trunk/boost/config/suffix.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -639,6 +639,10 @@
# if defined(unix) || defined(__unix) || defined(_XOPEN_SOURCE) \
|| defined(_POSIX_SOURCE)
# define BOOST_PLATFORM "Generic Unix"
+# define BOOST_NIX 1
+//# define BOOST_GENETIC_NIX 1
+//# define BOOST_TRADEMARK_NIX 1
+# define BOOST_FUNCTIONAL_NIX 1
# else
# define BOOST_PLATFORM "Unknown"
# endif
Modified: trunk/libs/config/doc/html/boost_config/boost_macro_reference.html
==============================================================================
--- trunk/libs/config/doc/html/boost_config/boost_macro_reference.html (original)
+++ trunk/libs/config/doc/html/boost_config/boost_macro_reference.html 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -3404,6 +3404,96 @@
<tr>
<td>
<p>
+ <code class="computeroutput"><span class="identifier">BOOST_LINUX</span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ <code class="computeroutput"><span class="special"><</span><span class="identifier">boost</span><span class="special">/</span><span class="identifier">config</span><span class="special">.</span><span class="identifier">hpp</span><span class="special">></span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ Defined if the system kernel is Linux
+ </p>
+ </td>
+</tr>
+<tr>
+<td>
+ <p>
+ <code class="computeroutput"><span class="identifier">BOOST_NIX</span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ <code class="computeroutput"><span class="special"><</span><span class="identifier">boost</span><span class="special">/</span><span class="identifier">config</span><span class="special">.</span><span class="identifier">hpp</span><span class="special">></span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ Defined if the system is POSIX compliant
+ </p>
+ </td>
+</tr>
+<tr>
+<td>
+ <p>
+ <code class="computeroutput"><span class="identifier">BOOST_GENETIC_NIX</span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ <code class="computeroutput"><span class="special"><</span><span class="identifier">boost</span><span class="special">/</span><span class="identifier">config</span><span class="special">.</span><span class="identifier">hpp</span><span class="special">></span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ Defined if the system can trace its ancestry to the original AT&T
+ codebase or designs, but is not certified by the Open Group. This
+ is the case for modern open-source BSD systems.
+ </p>
+ </td>
+</tr>
+<tr>
+<td>
+ <p>
+ <code class="computeroutput"><span class="identifier">BOOST_TRADEMARK_NIX</span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ <code class="computeroutput"><span class="special"><</span><span class="identifier">boost</span><span class="special">/</span><span class="identifier">config</span><span class="special">.</span><span class="identifier">hpp</span><span class="special">></span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ Systems certified as POSIX compliant by the Open Group. These systems
+ can use the UNIX trademark. Most commercially developed *nix systems
+ fall into this category.
+ </p>
+ </td>
+</tr>
+<tr>
+<td>
+ <p>
+ <code class="computeroutput"><span class="identifier">BOOST_FUNCTIONAL_NIX</span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ <code class="computeroutput"><span class="special"><</span><span class="identifier">boost</span><span class="special">/</span><span class="identifier">config</span><span class="special">.</span><span class="identifier">hpp</span><span class="special">></span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ Systems which behave in a manner roughly consistent with POSIX
+ standards. Linux and Minix fall into this category.
+ </p>
+ </td>
+</tr>
+<tr>
+<td>
+ <p>
<code class="computeroutput"><span class="identifier">BOOST_DINKUMWARE_STDLIB</span></code>
</p>
</td>
Modified: trunk/libs/config/doc/html/index.html
==============================================================================
--- trunk/libs/config/doc/html/index.html (original)
+++ trunk/libs/config/doc/html/index.html 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -28,7 +28,7 @@
</h3></div></div></div>
<div><p class="copyright">Copyright © 2001 -2007 Beman Dawes, Vesa Karvonen, John Maddock</p></div>
<div><div class="legalnotice">
-<a name="id663915"></a><p>
+<a name="id833182"></a><p>
Distributed under the Boost Software License, Version 1.0. (See accompanying
file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
</p>
@@ -946,7 +946,7 @@
</div>
</div>
<table xmlns:rev="http://www.cs.rpi.edu/~gregod/boost/tools/doc/revision" width="100%"><tr>
-<td align="left"><p><small>Last revised: November 23, 2010 at 03:21:20 GMT</small></p></td>
+<td align="left"><p><small>Last revised: November 23, 2010 at 05:40:40 GMT</small></p></td>
<td align="right"><div class="copyright-footer"></div></td>
</tr></table>
<hr>
Modified: trunk/libs/config/doc/macro_reference.qbk
==============================================================================
--- trunk/libs/config/doc/macro_reference.qbk (original)
+++ trunk/libs/config/doc/macro_reference.qbk 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -850,6 +850,26 @@
[[`BOOST_WINDOWS`][`<boost/config.hpp>`][
Defined if the Windows platfrom API is available.
]]
+[[`BOOST_LINUX`][`<boost/config.hpp>`][
+Defined if the system kernel is Linux
+]]
+[[`BOOST_NIX`][`<boost/config.hpp>`][
+Defined if the system is POSIX compliant
+]]
+[[`BOOST_GENETIC_NIX`][`<boost/config.hpp>`][
+Defined if the system can trace its ancestry to the original AT&T codebase or
+designs, but is not certified by the Open Group. This is the case for modern
+open-source BSD systems.
+]]
+[[`BOOST_TRADEMARK_NIX`][`<boost/config.hpp>`][
+Systems certified as POSIX compliant by the Open Group. These systems can use
+the UNIX trademark. Most commercially developed *nix systems fall into this
+category.
+]]
+[[`BOOST_FUNCTIONAL_NIX`][`<boost/config.hpp>`][
+Systems which behave in a manner roughly consistent with POSIX standards. Linux
+and Minix fall into this category.
+]]
[[`BOOST_DINKUMWARE_STDLIB`][`<boost/config.hpp>`][
Defined if the dinkumware standard library is in use, takes the same value
as the Dinkumware library version macro `_CPPLIB_VER` if defined, otherwise 1.
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- trunk/boost/config/platform/cygwin.hpp (original)
+++ trunk/boost/config/platform/cygwin.hpp 2010-11-23 01:33:35 EST (Tue, 23 Nov 2010)
@@ -1,52 +1,53 @@
-// (C) Copyright John Maddock 2001 - 2003.
-// Use, modification and distribution are subject to the
-// Boost Software License, Version 1.0. (See accompanying file
-// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
-
-// See http://www.boost.org for most recent version.
+// (C) Copyright John Maddock 2001 - 2003
+// (C) Copyright Bryce Lelbach 2010
+//
+// Use, modification and distribution are subject to the
+// Boost Software License, Version 1.0. (See accompanying file
+// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
+// See http://www.boost.org for most recent version.
-// cygwin specific config options:
+#define BOOST_PLATFORM "Cygwin" // Platform name.
+#define BOOST_CYGWIN __CYGWIN__ // Boost platform ID macros.
-#define BOOST_PLATFORM "Cygwin"
#define BOOST_HAS_DIRENT_H
#define BOOST_HAS_LOG1P
#define BOOST_HAS_EXPM1
-//
-// Threading API:
-// See if we have POSIX threads, if we do use them, otherwise
-// revert to native Win threads.
+#define BOOST_NIX 1
+//#define BOOST_GENETIC_NIX 1
+//#define BOOST_TRADEMARK_NIX 1
+#define BOOST_FUNCTIONAL_NIX 1
+
+// See if we have POSIX threads, otherwise revert to native Win threads.
#define BOOST_HAS_UNISTD_H
#include <unistd.h>
-#if defined(_POSIX_THREADS) && (_POSIX_THREADS+0 >= 0) && !defined(BOOST_HAS_WINTHREADS)
-# define BOOST_HAS_PTHREADS
-# define BOOST_HAS_SCHED_YIELD
-# define BOOST_HAS_GETTIMEOFDAY
-# define BOOST_HAS_PTHREAD_MUTEXATTR_SETTYPE
-# define BOOST_HAS_SIGACTION
+
+#if defined(_POSIX_THREADS) && (_POSIX_THREADS + 0 >= 0) && \
+ !defined(BOOST_HAS_WINTHREADS)
+ #define BOOST_HAS_PTHREADS
+ #define BOOST_HAS_SCHED_YIELD
+ #define BOOST_HAS_GETTIMEOFDAY
+ #define BOOST_HAS_PTHREAD_MUTEXATTR_SETTYPE
+ #define BOOST_HAS_SIGACTION
#else
-# if !defined(BOOST_HAS_WINTHREADS)
-# define BOOST_HAS_WINTHREADS
-# endif
-# define BOOST_HAS_FTIME
+ #if !defined(BOOST_HAS_WINTHREADS)
+ #define BOOST_HAS_WINTHREADS
+ #endif
+ #define BOOST_HAS_FTIME
#endif
-//
-// find out if we have a stdint.h, there should be a better way to do this:
-//
+// Find out if we have a stdint.h, there should be a better way to do this.
#include <sys/types.h>
+
#ifdef _STDINT_H
-#define BOOST_HAS_STDINT_H
+ #define BOOST_HAS_STDINT_H
#endif
-// boilerplate code:
#include <boost/config/posix_features.hpp>
-//
-// Cygwin lies about XSI conformance, there is no nl_types.h:
-//
+// Cygwin lies about XSI conformance, there is no nl_types.h.
#ifdef BOOST_HAS_NL_TYPES_H
-# undef BOOST_HAS_NL_TYPES_H
+ #undef BOOST_HAS_NL_TYPES_H
#endif
Modified: trunk/boost/config/platform/hpux.hpp
==============================================================================